==> GANN-1.2.tar.gz: GANN/src/gerrstat.cpp <==
/* 

   Geeks Artificial Neural Network (G.A.N.N) - Error Statistics
   
   Copyright GNU/GPL 2005-2006 George Delaportas (qtgeo)
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

*/



#if defined __GANN__
#define __GERRSTAT__

//Geeks Error Statistics (Function)
float GErrStat(float *FirstData,float *LastData,float *AltData,int StatType)

{

    //Variables
    int i,j;			//Counters
    int Faults;			//Faults Counter
    float OK,Error;		//OK And Error Values (%)
    
    //Reset Statistics
    OK=0.0;
    Error=0.0;
    
    //Reset Faults Counter
    Faults=0;
    
    //Check Statistics Type
    if (StatType<0 OR StatType>1)
        GExit(1,"Error:Wrong Statistics Type Specified!\n");
    
    else if (StatType==0)
    
    {
    
        for (i=0;i<Outputs;i++)
        
        {
        
            if (FirstData[i]!=LastData[i])
                Faults++;
        
        }
    
    }
    
    else
    
    {
    
        for (i=0;i<Outputs;i++)
        
        {
        
            if (LastData[i]<OutSocket.GetPV(i,0)
            OR AltData[i]>OutSocket.GetPV(i,1))
                Faults++;
        
        }
    
    }
    
    //Statistics (%)
    OK=((Outputs-Faults)/Outputs)*100.0;
    Error=100.0-OK;
    
    //User Messages
    printf("Correct:%.1f%%\n",OK);
    printf("Error:%.1f%%\n\n",Error);
    
    return Error;

}

#endif

/* ------------------------------------------------------------------------ */

==> GANN-1.3.tar.gz: GANN/src/gerrstat.cpp <==
/* 

   Geeks Artificial Neural Network (G.A.N.N) - Error Statistics
   
   Copyright GNU/GPL 2005-2006 George Delaportas (qtgeo)
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

*/



#if defined __GMAIN__
#define __GERRSTAT__

//Geeks Error Statistics (Function)
float GErrStat(float *FirstData,float *LastData,float *AltData,int StatType)

{

    //Variables
    int i,j;			//Counters
    int Faults;			//Faults Counter
    float OK,Error;		//OK And Error Values (%)
    
    //Reset Statistics
    OK=0.0;
    Error=0.0;
    
    //Reset Faults Counter
    Faults=0;
    
    //Check Statistics Type
    if (StatType<0 OR StatType>1)
        GExit(1,"Error:Wrong Statistics Type Specified!\n");
    
    else if (StatType==0)
    
    {
    
        for (i=0;i<Outputs;i++)
        
        {
        
            if (FirstData[i]!=LastData[i])
                Faults++;
        
        }
    
    }
    
    else
    
    {
    
        for (i=0;i<Outputs;i++)
        
        {
        
            if (LastData[i]<OutSocket.GetPV(i,0)
            OR AltData[i]>OutSocket.GetPV(i,1))
                Faults++;
        
        }
    
    }
    
    //Statistics (%)
    OK=((Outputs-Faults)/Outputs)*100.0;
    Error=100.0-OK;
    
    //User Messages
    printf("Correct:%.1f%%\n",OK);
    printf("Error:%.1f%%\n\n",Error);
    
    return Error;

}

#endif

/* ------------------------------------------------------------------------ */
